@@ -53,7 +53,7 @@ def fis_light_theme():
     dark_theme_colors + ["#b30000", "#7c1158", "#4421af", "#1a53ff", "#0d88e6", "#00b7c7", "#5ad45a", "#8be04e", "#ebdc78"]
     dark_theme_colors + ["#ea5545", "#f46a9b", "#ef9b20", "#edbf33", "#ede15b", "#bdcf32", "#87bc45", "#27aeef", "#b33dc6"]
     rcParams['figure.figsize'] = 9,4
-    rcParams['axes.edgecolor'] = "#545aa7"
+    rcParams['axes.edgecolor'] = dark_blue 
     rcParams['axes.grid'] = True
     rcParams['grid.alpha'] = .5
     rcParams['axes.prop_cycle'] = cycler(color=dark_theme_colors)
